bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 34. Aventiure
___________________________________________________
| ### <Di> herren nach ir mvede sazen do ce tal ### Volker vnde Hagene giengen fver den sal ### sich leinten veber schilde di vebermvten man ### do wart da rede vil spæhe von in beiden getan ### Do sprach von Bvergonden Giselher der degen ### iane mveget ir liebe vrivnde rwe niht gepflegen ### ir svlt di toten livte vz dem hvse tragen ### wir werden noch bestanden ich wilz iv wærliche sagen
###### 2008 | ### Sine svln vns vnder fvezen hi niht langer ligen ### ê daz vns di Hivnen mit stvrme an gesigen ### wir gehawoen noch di wnden di mir sanfte tvt ### des han ich sprach do Giselher einen stætigen mvt
| ### So wol mich soelhes herren sprach do Hagene ### der rat enzæme niemen wan einem degene ### den vns min ivnger herre hivte hat getan ### des mveget ir Bvergonden alle vil vroeliche stan
###### 2010 | ### Do volgeten si dem rate vnt tvrgen fver de tver ### siben tvsent toten wrfen si darfver ### vor des sales stiegen da vielen si ce tal ### do hvb sich von ir magen ein vil chlagelicher schal
###### 2011 | ### Ez was ir etlicher so mæzlichen wnt ### der sin sapfter pflæge er verde noch gesvnt ### der vor dem hohen valle mvese ligen tot ### daz chlageten do ir frivnde des gi in wærliche not
| ### Do sprach der videlære Volker ein helt gemeit ### nv chivse ich des die warheit als mir ist geseit ### di Hivnen di sint boese si clagent sam div wip ### nv solden si bervchen der vil sere wnden lip
###### 2013 | ### Do wande ein margrave er riet iz dvrch gvt ### er sach einen sinen mach gevallen in daz plvt ### er besloz in mit den armen vnde wold in tragen dan ### den schoz ob im ce tode der vil chvene spileman
###### 2014 | ### Do daz di ander sahen div flvht div [393a] hvop sich dan ### si begonden alle vlvchen dem selbem spileman ### einen gere er vf gezvchte vil scharpf vnde vil hart ### der von einem Hivnen zv zim dar vf geschozen wart
| ### Den shoz er crepftelichen dvrch di bvrch dan ### veber daz volch vil verre den Eceln man ### gap er herberge hoher von dem sal ### sin vil starchez ellen di livte vorhten veber al
###### 2016 | ### So stvnden vor dem hvse vil manech tvsent man ### Volker vnde Hagene reden do began ### mit Ecel dem chvenege allen iren mvt ### des chomen sit in sorge di helde chvene vnd gvt
###### 2017 | ### Ez zæme so sprach Hagene vil wol volches trost ### daz di herren vehten zaller vorderost ### also der minen herren hi ieslicher tvt ### di howent dvrch di helme nach swerten vlivzet daz plvt
| ### Ecel was so chvene er vazete sinen schilt ### nv vart gewerliche sprach vrov Criemhilt ### vnde bietet ir den recken daz golt veber rant ### wande erreichet ivch dort Hagene ir habt den tot an der hant
###### 2019 | ### Der chvenech der was so chvene er wold erwinden niht ### daz von so richem fversten vil selten nv geschit ### man mvse in bi dem vezel ziehen wider dan ### Hagen der grimme in aber hoenen began
###### 2020 | ### Ez was ein verriv sippe sprach Hagen der degen ### di Ecel vnde Sifrit cesamne heten gepflegen ### er minnete Criemhilden ê si ie gesæhe dich ### kvenech vil boese war vmbe rætest an mich
| ### Dise rede horte des edeln chveneges wip ### des wart in vngemvete der Criemhilde lip ### daz er si getorste shelten vor Eceln man ### dar vmbe si aber raten an di geste began
###### 2022 | ### Si sprach der mir von Tronege Hagenen slvege ### vnde mir sin hovbet her fver mich trvege ### dem fvlt ich rotes goldes den Eceln rant ### dar zv gæbe ich im ce miete vil gvte [393b] bverge vnde lant
###### 2023 | ### Nv weiz ich wes si bitent sprach der spilman ### ine gesach ni helde so zægelichen stan ### da man horte bieten also hohen solt ### iane sol in Ecel dar vmbe nimmer werden holt
###### 2024 | ### <Di> hi so lasterlichen ezzent des fversten brot ### vnde im nv geswichent in der groezesten not ### der sihe ich hi vil manegen vil zageliche stan ### vnde wellent doch sin vil chvene si mvzens immer schaden han

<<< Übersicht <<< vorige Seite nächste Seite >>>